@@ -936,6 +936,9 @@ _expectations = {
         """,
      'openbsd3':
          """
+       test_audioop
+       test_rgbimg
+       test_imageop
        test_aepack
        test_al
        test_cd
