@@ -24,7 +24,7 @@ if sys.platform in ('netbsd1', 'Darwin1.2', 'darwin',
                     'freebsd2', 'freebsd3', 'freebsd4', 'freebsd5',
                     'bsdos2', 'bsdos3', 'bsdos4'):
     lockdata = struct.pack('lxxxxlxxxxlhh', 0, 0, 0, fcntl.F_WRLCK, 0)
-elif sys.platform in ['openbsd', 'openbsd2', 'openbsd3']:
+elif sys.platform in ['openbsd', 'openbsd2', 'openbsd3', 'openbsd4']:
     if sys.maxint == 2147483647:
         lockdata = struct.pack('lxxxxlxxxxlhh', 0, 0, 0, fcntl.F_WRLCK, 0)
     else:
