@@ -1,5 +1,5 @@
 # regression test for SAX 2.0            -*- coding: iso-8859-1 -*-
-# $Id: test_sax.py,v 1.24 2002/10/28 17:58:48 fdrake Exp $
+# $Id: test_sax.py 36572 2004-07-18 18:36:18Z loewis $
 
 from xml.sax import make_parser, ContentHandler, \
                     SAXException, SAXReaderNotAvailable, SAXParseException
@@ -27,7 +27,7 @@ def confirm(outcome, name):
     tests = tests + 1
     if outcome:
         if verbose:
-            print "Failed", name
+            print "Passed", name
     else:
         failures.append(name)
 
